from sports.nba.nba_team import NBA_Team


class IndianaPacers(NBA_Team):
    """
    NBA Atlanta Hawks Static Information

    """
    full_name = "Indiana Pacers"
    name = "Pacers"
    team_id = 1610612754
    def __init__(self):
        """
        """
        super().__init__()
